
# Class: ClassifierContainer


A container with multiple classifiers in it.

URI: [https://w3id.org/neat/ClassifierContainer](https://w3id.org/neat/ClassifierContainer)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[Classifier]<classifiers%200..*-++[ClassifierContainer],[Classifier])](https://yuml.me/diagram/nofunky;dir:TB/class/[Classifier]<classifiers%200..*-++[ClassifierContainer],[Classifier])

## Attributes


### Own

 * [➞classifiers](classifierContainer__classifiers.md)  <sub>0..\*</sub>
     * Description: Classifier details.
     * Range: [Classifier](Classifier.md)
